CMS Code Reference
==================

Bundle
------

.. autoclass:: scarlet.cms.bundles.Bundle
    :members:

.. autoclass:: scarlet.cms.bundles.BundleMeta
    :members:

.. autoclass:: scarlet.cms.bundles.ChildBundle
    :members:

.. autoclass:: scarlet.cms.bundles.VersionedBundle
    :members:

.. autoclass:: scarlet.cms.bundles.ParentVersionedBundle
    :members:

.. autoclass:: scarlet.cms.bundles.ObjectOnlyBundle
    :members:

.. autoclass:: scarlet.cms.bundles.VersionedObjectOnlyBundle
    :members:

.. autoclass:: scarlet.cms.bundles.DelegatedObjectBundle
    :members:

.. autoclass:: scarlet.cms.bundles.BlankBundle
    :members:

.. autoclass:: scarlet.cms.bundles.URLAlias
    :members:

.. automodule:: scarlet.cms.options
    :members:

Template tags
~~~~~~~~~~~~~

.. automodule:: scarlet.cms.templatetags.cms
    :members:

Views
-----

.. autoclass:: scarlet.cms.views.BaseView
    :members:

.. autoclass:: scarlet.cms.views.SiteView
    :members:

.. autoclass:: scarlet.cms.views.CMSView
    :members:

.. autoclass:: scarlet.cms.views.ModelCMSView
    :members:

.. autoclass:: scarlet.cms.views.ModelCMSMixin
    :members:

.. autoclass:: scarlet.cms.views.ListView
    :members:

.. autoclass:: scarlet.cms.views.FormView
    :members:

.. autoclass:: scarlet.cms.actions.ActionView
    :members:

.. autoclass:: scarlet.cms.actions.DeleteActionView
    :members:

.. autoclass:: scarlet.cms.actions.PublishActionView
    :members:

.. autoclass:: scarlet.cms.actions.UnPublishActionView
    :members:

.. autoclass:: scarlet.cms.views.PreviewWrapper
    :members:

.. autoclass:: scarlet.cms.views.VersionsList
    :members:


Forms
~~~~~

.. automodule:: scarlet.cms.forms
    :members:

Fields
~~~~~~

.. automodule:: scarlet.cms.fields
    :members:

Widgets
~~~~~~~

.. automodule:: scarlet.cms.widgets
    :members:

Renderers
~~~~~~~~~

.. autoclass:: scarlet.cms.renders.RenderResponse
    :members:

.. autoclass:: scarlet.cms.renders.CMSRender
    :members:

.. autoclass:: scarlet.cms.renders.RenderString
    :members:

.. autoclass:: scarlet.cms.renders.PopupRender
    :members:

.. autoclass:: scarlet.cms.renders.ChoicesRender
    :members:

Sites
-----

.. automodule:: scarlet.cms.sites
    :members:
